15.2. cdist-type__apt_default_release(7) — cdist 4.10.4 documentation

# 15.2. cdist-type__apt_default_release(7)

## 15.2.1. NAME

cdist-type__apt_default_release - Configure the default release for apt

## 15.2.2. DESCRIPTION

Configure the default release for apt, using the APT::Default-Release configuration value.

## 15.2.3. REQUIRED PARAMETERS

release

  The value to set APT::Default-Release to.

  This can contain release name, codename or release version. Examples: 'stable', 'testing', 'unstable', 'stretch', 'buster', '4.0', '5.0*'.

## 15.2.4. OPTIONAL PARAMETERS

None.

## 15.2.5. EXAMPLES

    __apt_default_release --release stretch

## 15.2.6. AUTHORS

Matthijs Kooijman <matthijs--@--stdin.nl>

## 15.2.7. COPYING

Copyright (C) 2017 Matthijs Kooijman. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.